# system configuration generated and used by the sysconfig module
build_time_vars = {'ABIFLAGS': 'm',
 'AC_APPLE_UNIVERSAL_BUILD': 0,
 'AIX_GENUINE_CPLUSPLUS': 0,
 'AR': 'arm-jdsu-linux-gnueabi-ar',
 'ARCH': 'x86_64',
 'ARFLAGS': 'rc',
 'ASDLGEN': '/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux/usr/bin/python3-native/python3 '
            '../Python-3.5.2/Parser/asdl_c.py',
 'ASDLGEN_FILES': '../Python-3.5.2/Parser/asdl.py '
                  '../Python-3.5.2/Parser/asdl_c.py',
 'AST_ASDL': '../Python-3.5.2/Parser/Python.asdl',
 'AST_C': 'Python/Python-ast.c',
 'AST_C_DIR': 'Python',
 'AST_H': 'Include/Python-ast.h',
 'AST_H_DIR': 'Include',
 'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
 'BASECPPFLAGS': '',
 'BASEMODLIBS': '',
 'BINDIR': '/usr/bin',
 'BINLIBDEST': '/usr/lib/python3.5',
 'BLDLIBRARY': '-L. -lpython3.5m',
 'BLDSHARED': 'arm-jdsu-linux-gnueabi-gcc  -march=armv7-a -marm -mfpu=neon  '
              '-mfloat-abi=hard -mcpu=cortex-a9 -DNDEBUG -fno-inline '
              ' '
              '-shared -Wl,-O1 -Wl,--hash-style=gnu -Wl,--as-needed -Wl,-O1 '
              '-Wl,--hash-style=gnu -Wl,--as-needed',
 'BUILDEXE': '',
 'BUILDPYTHON': 'python',
 'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
 'BYTESTR_DEPS': '\\',
 'CC': 'arm-jdsu-linux-gnueabi-gcc  -march=armv7-a -marm -mfpu=neon  '
       '-mfloat-abi=hard -mcpu=cortex-a9 -DNDEBUG -fno-inline '
       '',
 'CCSHARED': '-fPIC',
 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall '
           '-Wstrict-prototypes -O2 -pipe -g -feliminate-unused-debug-types '
           '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
           '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
           '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2=  '
           '-O2 -pipe -g -feliminate-unused-debug-types '
           '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
           '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
           '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2=',
 'CFLAGSFORSHARED': '-fPIC',
 'CFLAGS_NODIST': '',
 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                'Makefile.pre.in',
 'CONFIGURE_CFLAGS': '-O2 -pipe -g -feliminate-unused-debug-types '
                     '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
                     '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
                     '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2=',
 'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
 'CONFIGURE_CPPFLAGS': '',
 'CONFIGURE_LDFLAGS': '-Wl,-O1 -Wl,--hash-style=gnu -Wl,--as-needed',
 'CONFIG_ARGS': "'--build=x86_64-linux' '--host=arm-jdsu-linux-gnueabi' "
                "'--target=arm-jdsu-linux-gnueabi' '--prefix=/usr' "
                "'--exec_prefix=/usr' '--bindir=/usr/bin' "
                "'--sbindir=/usr/sbin' '--libexecdir=/usr/libexec' "
                "'--datadir=/usr/share' '--sysconfdir=/etc' "
                "'--sharedstatedir=/com' '--localstatedir=/var' "
                "'--libdir=/usr/lib' '--includedir=/usr/include' "
                "'--oldincludedir=/usr/include' '--infodir=/usr/share/info' "
                "'--mandir=/usr/share/man' '--disable-silent-rules' "
                "'--disable-dependency-tracking' "
                "'' "
                "'--with-system-ffi' '--with-threads' '--with-pymalloc' "
                "'--without-cxx-main' '--with-signal-module' '--enable-shared' "
                "'--enable-ipv6=yes' 'ac_cv_header_bluetooth_bluetooth_h=no' "
                "'ac_cv_header_bluetooth_h=no' "
                "'CROSSPYTHONPATH=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux/usr/lib/python3.5/lib-dynload/' "
                "'--without-ensurepip' 'build_alias=x86_64-linux' "
                "'host_alias=arm-jdsu-linux-gnueabi' "
                "'target_alias=arm-jdsu-linux-gnueabi' "
                "'CC=arm-jdsu-linux-gnueabi-gcc  -march=armv7-a -marm "
                '-mfpu=neon  -mfloat-abi=hard -mcpu=cortex-a9 -DNDEBUG '
                '-fno-inline '
                "' "
                "'CFLAGS= -O2 -pipe -g -feliminate-unused-debug-types "
                '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
                '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
                '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2= '
                "' 'LDFLAGS=-Wl,-O1 -Wl,--hash-style=gnu -Wl,--as-needed' "
                "'CPPFLAGS=' 'CPP=arm-jdsu-linux-gnueabi-gcc -E "
                '  '
                '-march=armv7-a -marm -mfpu=neon  -mfloat-abi=hard '
                "-mcpu=cortex-a9 -DNDEBUG -fno-inline' "
                "'PKG_CONFIG_PATH=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2/usr/lib/pkgconfig:/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2/usr/share/pkgconfig' "
                "'PKG_CONFIG_LIBDIR=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2/usr/lib/pkgconfig'",
 'CONFINCLUDEDIR': '/usr/include',
 'CONFINCLUDEPY': '/usr/include/python3.5m',
 'COREPYTHONPATH': ':plat-linux',
 'COVERAGE_INFO': '/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build/coverage.info',
 'COVERAGE_REPORT': '/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build/lcov-report',
 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                            'report"',
 'CPPFLAGS': '-I. -IInclude -I../Python-3.5.2/Include',
 'CXX': 'arm-jdsu-linux-gnueabi-g++  -march=armv7-a -marm -mfpu=neon  '
        '-mfloat-abi=hard -mcpu=cortex-a9 -DNDEBUG -fno-inline '
        '',
 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.5 /usr/lib/python3.5/lib-dynload',
 'DESTLIB': '/usr/lib/python3.5',
 'DESTPATH': '',
 'DESTSHARED': '/usr/lib/python3.5/lib-dynload',
 'DIRMODE': 755,
 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
         'Makefile.pre.in Include Lib Misc Ext-dummy',
 'DISTDIRS': 'Include Lib Misc Ext-dummy',
 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h '
              'pyconfig.h.in Makefile.pre.in',
 'DLINCLDIR': '.',
 'DLLLIBRARY': '',
 'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
 'DYNLOADFILE': 'dynload_shlib.o',
 'ENABLE_IPV6': 1,
 'ENSUREPIP': 'no',
 'EXE': '',
 'EXEMODE': 755,
 'EXTRAMACHDEPPATH': '',
 'EXTRATESTOPTS': '',
 'EXTRA_CFLAGS': '',
 'EXT_SUFFIX': '.cpython-35m-arm-linux-gnueabihf.so',
 'FILEMODE': 644,
 'FLOCK_NEEDS_LIBBSD': 0,
 'GETPGRP_HAVE_ARG': 0,
 'GETTIMEOFDAY_NO_TZ': 0,
 'GNULD': 'yes',
 'GRAMMAR_C': 'Python/graminit.c',
 'GRAMMAR_H': 'Include/graminit.h',
 'GRAMMAR_INPUT': '../Python-3.5.2/Grammar/Grammar',
 'HAVE_ACCEPT4': 1,
 'HAVE_ACOSH': 1,
 'HAVE_ADDRINFO': 1,
 'HAVE_ALARM': 1,
 'HAVE_ALIGNED_REQUIRED': 1,
 'HAVE_ALLOCA_H': 1,
 'HAVE_ALTZONE': 0,
 'HAVE_ASINH': 1,
 'HAVE_ASM_TYPES_H': 1,
 'HAVE_ATANH': 1,
 'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
 'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
 'HAVE_BLUETOOTH_H': 0,
 'HAVE_BROKEN_MBSTOWCS': 0,
 'HAVE_BROKEN_NICE': 0,
 'HAVE_BROKEN_PIPE_BUF': 0,
 'HAVE_BROKEN_POLL': 0,
 'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
 'HAVE_BROKEN_PTHREAD_SIGMASK': 0,
 'HAVE_BROKEN_SEM_GETVALUE': 1,
 'HAVE_BROKEN_UNSETENV': 0,
 'HAVE_BUILTIN_ATOMIC': 1,
 'HAVE_C99_BOOL': 1,
 'HAVE_CHFLAGS': 0,
 'HAVE_CHOWN': 1,
 'HAVE_CHROOT': 1,
 'HAVE_CLOCK': 1,
 'HAVE_CLOCK_GETRES': 1,
 'HAVE_CLOCK_GETTIME': 1,
 'HAVE_COMPUTED_GOTOS': 0,
 'HAVE_CONFSTR': 1,
 'HAVE_CONIO_H': 0,
 'HAVE_COPYSIGN': 1,
 'HAVE_CTERMID': 1,
 'HAVE_CTERMID_R': 0,
 'HAVE_CURSES_H': 1,
 'HAVE_CURSES_IS_TERM_RESIZED': 1,
 'HAVE_CURSES_RESIZETERM': 1,
 'HAVE_CURSES_RESIZE_TERM': 1,
 'HAVE_DECL_ISFINITE': 1,
 'HAVE_DECL_ISINF': 1,
 'HAVE_DECL_ISNAN': 1,
 'HAVE_DECL_TZNAME': 0,
 'HAVE_DEVICE_MACROS': 1,
 'HAVE_DEV_PTC': 0,
 'HAVE_DEV_PTMX': 1,
 'HAVE_DIRECT_H': 0,
 'HAVE_DIRENT_D_TYPE': 1,
 'HAVE_DIRENT_H': 1,
 'HAVE_DIRFD': 1,
 'HAVE_DLFCN_H': 1,
 'HAVE_DLOPEN': 1,
 'HAVE_DUP2': 1,
 'HAVE_DUP3': 1,
 'HAVE_DYNAMIC_LOADING': 1,
 'HAVE_ENDIAN_H': 1,
 'HAVE_EPOLL': 1,
 'HAVE_EPOLL_CREATE1': 1,
 'HAVE_ERF': 1,
 'HAVE_ERFC': 1,
 'HAVE_ERRNO_H': 1,
 'HAVE_EXECV': 1,
 'HAVE_EXPM1': 1,
 'HAVE_FACCESSAT': 1,
 'HAVE_FCHDIR': 1,
 'HAVE_FCHMOD': 1,
 'HAVE_FCHMODAT': 1,
 'HAVE_FCHOWN': 1,
 'HAVE_FCHOWNAT': 1,
 'HAVE_FCNTL_H': 1,
 'HAVE_FDATASYNC': 1,
 'HAVE_FDOPENDIR': 1,
 'HAVE_FEXECVE': 1,
 'HAVE_FINITE': 1,
 'HAVE_FLOCK': 1,
 'HAVE_FORK': 1,
 'HAVE_FORKPTY': 1,
 'HAVE_FPATHCONF': 1,
 'HAVE_FSEEK64': 0,
 'HAVE_FSEEKO': 1,
 'HAVE_FSTATAT': 1,
 'HAVE_FSTATVFS': 1,
 'HAVE_FSYNC': 1,
 'HAVE_FTELL64': 0,
 'HAVE_FTELLO': 1,
 'HAVE_FTIME': 1,
 'HAVE_FTRUNCATE': 1,
 'HAVE_FUTIMENS': 1,
 'HAVE_FUTIMES': 1,
 'HAVE_FUTIMESAT': 1,
 'HAVE_GAI_STRERROR': 1,
 'HAVE_GAMMA': 1,
 'HAVE_GCC_ASM_FOR_MC68881': 0,
 'HAVE_GCC_ASM_FOR_X64': 0,
 'HAVE_GCC_ASM_FOR_X87': 0,
 'HAVE_GCC_UINT128_T': 0,
 'HAVE_GETADDRINFO': 1,
 'HAVE_GETC_UNLOCKED': 1,
 'HAVE_GETENTROPY': 0,
 'HAVE_GETGROUPLIST': 1,
 'HAVE_GETGROUPS': 1,
 'HAVE_GETHOSTBYNAME': 0,
 'HAVE_GETHOSTBYNAME_R': 1,
 'HAVE_GETHOSTBYNAME_R_3_ARG': 0,
 'HAVE_GETHOSTBYNAME_R_5_ARG': 0,
 'HAVE_GETHOSTBYNAME_R_6_ARG': 1,
 'HAVE_GETITIMER': 1,
 'HAVE_GETLOADAVG': 1,
 'HAVE_GETLOGIN': 1,
 'HAVE_GETNAMEINFO': 1,
 'HAVE_GETPAGESIZE': 1,
 'HAVE_GETPEERNAME': 1,
 'HAVE_GETPGID': 1,
 'HAVE_GETPGRP': 1,
 'HAVE_GETPID': 1,
 'HAVE_GETPRIORITY': 1,
 'HAVE_GETPWENT': 1,
 'HAVE_GETRANDOM': 0,
 'HAVE_GETRANDOM_SYSCALL': 1,
 'HAVE_GETRESGID': 1,
 'HAVE_GETRESUID': 1,
 'HAVE_GETSID': 1,
 'HAVE_GETSPENT': 1,
 'HAVE_GETSPNAM': 1,
 'HAVE_GETTIMEOFDAY': 1,
 'HAVE_GETWD': 1,
 'HAVE_GLIBC_MEMMOVE_BUG': 0,
 'HAVE_GRP_H': 1,
 'HAVE_HSTRERROR': 1,
 'HAVE_HTOLE64': 1,
 'HAVE_HYPOT': 1,
 'HAVE_IEEEFP_H': 0,
 'HAVE_IF_NAMEINDEX': 1,
 'HAVE_INET_ATON': 1,
 'HAVE_INET_PTON': 1,
 'HAVE_INITGROUPS': 1,
 'HAVE_INT32_T': 1,
 'HAVE_INT64_T': 1,
 'HAVE_INTTYPES_H': 1,
 'HAVE_IO_H': 0,
 'HAVE_IPA_PURE_CONST_BUG': 0,
 'HAVE_KILL': 1,
 'HAVE_KILLPG': 1,
 'HAVE_KQUEUE': 0,
 'HAVE_LANGINFO_H': 1,
 'HAVE_LARGEFILE_SUPPORT': 1,
 'HAVE_LCHFLAGS': 0,
 'HAVE_LCHMOD': 0,
 'HAVE_LCHOWN': 1,
 'HAVE_LGAMMA': 1,
 'HAVE_LIBDL': 1,
 'HAVE_LIBDLD': 0,
 'HAVE_LIBIEEE': 0,
 'HAVE_LIBINTL_H': 1,
 'HAVE_LIBREADLINE': 1,
 'HAVE_LIBRESOLV': 0,
 'HAVE_LIBSENDFILE': 0,
 'HAVE_LIBUTIL_H': 0,
 'HAVE_LINK': 1,
 'HAVE_LINKAT': 1,
 'HAVE_LINUX_CAN_BCM_H': 1,
 'HAVE_LINUX_CAN_H': 1,
 'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
 'HAVE_LINUX_CAN_RAW_H': 1,
 'HAVE_LINUX_NETLINK_H': 1,
 'HAVE_LINUX_RANDOM_H': 1,
 'HAVE_LINUX_TIPC_H': 1,
 'HAVE_LOCKF': 1,
 'HAVE_LOG1P': 1,
 'HAVE_LOG2': 1,
 'HAVE_LONG_DOUBLE': 1,
 'HAVE_LONG_LONG': 1,
 'HAVE_LSTAT': 1,
 'HAVE_LUTIMES': 1,
 'HAVE_MAKEDEV': 1,
 'HAVE_MBRTOWC': 1,
 'HAVE_MEMMOVE': 1,
 'HAVE_MEMORY_H': 1,
 'HAVE_MEMRCHR': 1,
 'HAVE_MKDIRAT': 1,
 'HAVE_MKFIFO': 1,
 'HAVE_MKFIFOAT': 1,
 'HAVE_MKNOD': 1,
 'HAVE_MKNODAT': 1,
 'HAVE_MKTIME': 1,
 'HAVE_MMAP': 1,
 'HAVE_MREMAP': 1,
 'HAVE_NCURSES_H': 1,
 'HAVE_NDIR_H': 0,
 'HAVE_NETPACKET_PACKET_H': 1,
 'HAVE_NET_IF_H': 1,
 'HAVE_NICE': 1,
 'HAVE_OPENAT': 1,
 'HAVE_OPENPTY': 1,
 'HAVE_OSX105_SDK': 0,
 'HAVE_PATHCONF': 1,
 'HAVE_PAUSE': 1,
 'HAVE_PIPE2': 1,
 'HAVE_PLOCK': 0,
 'HAVE_POLL': 1,
 'HAVE_POLL_H': 1,
 'HAVE_POSIX_FADVISE': 1,
 'HAVE_POSIX_FALLOCATE': 1,
 'HAVE_PREAD': 1,
 'HAVE_PRLIMIT': 1,
 'HAVE_PROCESS_H': 0,
 'HAVE_PROTOTYPES': 1,
 'HAVE_PTHREAD_ATFORK': 1,
 'HAVE_PTHREAD_DESTRUCTOR': 0,
 'HAVE_PTHREAD_H': 1,
 'HAVE_PTHREAD_INIT': 0,
 'HAVE_PTHREAD_KILL': 1,
 'HAVE_PTHREAD_SIGMASK': 1,
 'HAVE_PTY_H': 1,
 'HAVE_PUTENV': 1,
 'HAVE_PWRITE': 1,
 'HAVE_RAND_EGD': 1,
 'HAVE_READLINK': 1,
 'HAVE_READLINKAT': 1,
 'HAVE_READV': 1,
 'HAVE_REALPATH': 1,
 'HAVE_RENAMEAT': 1,
 'HAVE_RL_APPEND_HISTORY': 1,
 'HAVE_RL_CALLBACK': 1,
 'HAVE_RL_CATCH_SIGNAL': 1,
 'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
 'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
 'HAVE_RL_COMPLETION_MATCHES': 1,
 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
 'HAVE_RL_PRE_INPUT_HOOK': 1,
 'HAVE_RL_RESIZE_TERMINAL': 1,
 'HAVE_ROUND': 1,
 'HAVE_SCHED_GET_PRIORITY_MAX': 1,
 'HAVE_SCHED_H': 1,
 'HAVE_SCHED_RR_GET_INTERVAL': 1,
 'HAVE_SCHED_SETAFFINITY': 1,
 'HAVE_SCHED_SETPARAM': 1,
 'HAVE_SCHED_SETSCHEDULER': 1,
 'HAVE_SELECT': 1,
 'HAVE_SEM_GETVALUE': 1,
 'HAVE_SEM_OPEN': 1,
 'HAVE_SEM_TIMEDWAIT': 1,
 'HAVE_SEM_UNLINK': 1,
 'HAVE_SENDFILE': 1,
 'HAVE_SETEGID': 1,
 'HAVE_SETEUID': 1,
 'HAVE_SETGID': 1,
 'HAVE_SETGROUPS': 1,
 'HAVE_SETHOSTNAME': 1,
 'HAVE_SETITIMER': 1,
 'HAVE_SETLOCALE': 1,
 'HAVE_SETPGID': 1,
 'HAVE_SETPGRP': 1,
 'HAVE_SETPRIORITY': 1,
 'HAVE_SETREGID': 1,
 'HAVE_SETRESGID': 1,
 'HAVE_SETRESUID': 1,
 'HAVE_SETREUID': 1,
 'HAVE_SETSID': 1,
 'HAVE_SETUID': 1,
 'HAVE_SETVBUF': 1,
 'HAVE_SHADOW_H': 1,
 'HAVE_SIGACTION': 1,
 'HAVE_SIGALTSTACK': 1,
 'HAVE_SIGINTERRUPT': 1,
 'HAVE_SIGNAL_H': 1,
 'HAVE_SIGPENDING': 1,
 'HAVE_SIGRELSE': 1,
 'HAVE_SIGTIMEDWAIT': 1,
 'HAVE_SIGWAIT': 1,
 'HAVE_SIGWAITINFO': 1,
 'HAVE_SNPRINTF': 1,
 'HAVE_SOCKADDR_SA_LEN': 0,
 'HAVE_SOCKADDR_STORAGE': 1,
 'HAVE_SOCKETPAIR': 1,
 'HAVE_SPAWN_H': 1,
 'HAVE_SSIZE_T': 1,
 'HAVE_STATVFS': 1,
 'HAVE_STAT_TV_NSEC': 1,
 'HAVE_STAT_TV_NSEC2': 0,
 'HAVE_STDARG_PROTOTYPES': 1,
 'HAVE_STDINT_H': 1,
 'HAVE_STDLIB_H': 1,
 'HAVE_STD_ATOMIC': 1,
 'HAVE_STRDUP': 1,
 'HAVE_STRFTIME': 1,
 'HAVE_STRINGS_H': 1,
 'HAVE_STRING_H': 1,
 'HAVE_STRLCPY': 0,
 'HAVE_STROPTS_H': 1,
 'HAVE_STRUCT_STAT_ST_BIRTHTIME': 0,
 'HAVE_STRUCT_STAT_ST_BLKSIZE': 1,
 'HAVE_STRUCT_STAT_ST_BLOCKS': 1,
 'HAVE_STRUCT_STAT_ST_FLAGS': 0,
 'HAVE_STRUCT_STAT_ST_GEN': 0,
 'HAVE_STRUCT_STAT_ST_RDEV': 1,
 'HAVE_STRUCT_TM_TM_ZONE': 1,
 'HAVE_SYMLINK': 1,
 'HAVE_SYMLINKAT': 1,
 'HAVE_SYNC': 1,
 'HAVE_SYSCONF': 1,
 'HAVE_SYSEXITS_H': 1,
 'HAVE_SYS_AUDIOIO_H': 0,
 'HAVE_SYS_BSDTTY_H': 0,
 'HAVE_SYS_DEVPOLL_H': 0,
 'HAVE_SYS_DIR_H': 0,
 'HAVE_SYS_ENDIAN_H': 0,
 'HAVE_SYS_EPOLL_H': 1,
 'HAVE_SYS_EVENT_H': 0,
 'HAVE_SYS_FILE_H': 1,
 'HAVE_SYS_IOCTL_H': 1,
 'HAVE_SYS_KERN_CONTROL_H': 0,
 'HAVE_SYS_LOADAVG_H': 0,
 'HAVE_SYS_LOCK_H': 0,
 'HAVE_SYS_MKDEV_H': 0,
 'HAVE_SYS_MODEM_H': 0,
 'HAVE_SYS_NDIR_H': 0,
 'HAVE_SYS_PARAM_H': 1,
 'HAVE_SYS_POLL_H': 1,
 'HAVE_SYS_RESOURCE_H': 1,
 'HAVE_SYS_SELECT_H': 1,
 'HAVE_SYS_SENDFILE_H': 1,
 'HAVE_SYS_SOCKET_H': 1,
 'HAVE_SYS_STATVFS_H': 1,
 'HAVE_SYS_STAT_H': 1,
 'HAVE_SYS_SYSCALL_H': 1,
 'HAVE_SYS_SYS_DOMAIN_H': 0,
 'HAVE_SYS_TERMIO_H': 0,
 'HAVE_SYS_TIMES_H': 1,
 'HAVE_SYS_TIME_H': 1,
 'HAVE_SYS_TYPES_H': 1,
 'HAVE_SYS_UIO_H': 1,
 'HAVE_SYS_UN_H': 1,
 'HAVE_SYS_UTSNAME_H': 1,
 'HAVE_SYS_WAIT_H': 1,
 'HAVE_SYS_XATTR_H': 1,
 'HAVE_TCGETPGRP': 1,
 'HAVE_TCSETPGRP': 1,
 'HAVE_TEMPNAM': 1,
 'HAVE_TERMIOS_H': 1,
 'HAVE_TERM_H': 1,
 'HAVE_TGAMMA': 1,
 'HAVE_TIMEGM': 1,
 'HAVE_TIMES': 1,
 'HAVE_TMPFILE': 1,
 'HAVE_TMPNAM': 1,
 'HAVE_TMPNAM_R': 1,
 'HAVE_TM_ZONE': 1,
 'HAVE_TRUNCATE': 1,
 'HAVE_TZNAME': 0,
 'HAVE_UCS4_TCL': 0,
 'HAVE_UINT32_T': 1,
 'HAVE_UINT64_T': 1,
 'HAVE_UINTPTR_T': 1,
 'HAVE_UNAME': 1,
 'HAVE_UNISTD_H': 1,
 'HAVE_UNLINKAT': 1,
 'HAVE_UNSETENV': 1,
 'HAVE_USABLE_WCHAR_T': 0,
 'HAVE_UTIL_H': 0,
 'HAVE_UTIMENSAT': 1,
 'HAVE_UTIMES': 1,
 'HAVE_UTIME_H': 1,
 'HAVE_WAIT3': 1,
 'HAVE_WAIT4': 1,
 'HAVE_WAITID': 1,
 'HAVE_WAITPID': 1,
 'HAVE_WCHAR_H': 1,
 'HAVE_WCSCOLL': 1,
 'HAVE_WCSFTIME': 1,
 'HAVE_WCSXFRM': 1,
 'HAVE_WMEMCMP': 1,
 'HAVE_WORKING_TZSET': 0,
 'HAVE_WRITEV': 1,
 'HAVE_ZLIB_COPY': 1,
 'HAVE__GETPTY': 0,
 'HGBRANCH': '',
 'HGTAG': '',
 'HGVERSION': '',
 'HOSTPGEN': 'Parser/pgen',
 'HOSTPYTHON': 'python',
 'HOST_GNU_TYPE': 'arm-jdsu-linux-gnueabi',
 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.5m '
                   '/usr/include/python3.5m',
 'INCLUDEDIR': '/usr/include',
 'INCLUDEPY': '/usr/include/python3.5m',
 'INSTALL': '/usr/bin/install -c',
 'INSTALL_DATA': '/usr/bin/install -c -m 644',
 'INSTALL_PROGRAM': '/usr/bin/install -c',
 'INSTALL_SCRIPT': '/usr/bin/install -c',
 'INSTALL_SHARED': '/usr/bin/install -c -m 555',
 'INSTSONAME': 'libpython3.5m.so.1.0',
 'IO_H': 'Modules/_io/_iomodule.h',
 'IO_OBJS': '\\',
 'LDCXXSHARED': 'arm-jdsu-linux-gnueabi-g++  -march=armv7-a -marm -mfpu=neon  '
                '-mfloat-abi=hard -mcpu=cortex-a9 -DNDEBUG -fno-inline '
                ' '
                '-shared',
 'LDFLAGS': '-Wl,-O1 -Wl,--hash-style=gnu -Wl,--as-needed -Wl,-O1 '
            '-Wl,--hash-style=gnu -Wl,--as-needed',
 'LDLAST': '',
 'LDLIBRARY': 'libpython3.5m.so',
 'LDLIBRARYDIR': '',
 'LDSHARED': 'arm-jdsu-linux-gnueabi-gcc  -march=armv7-a -marm -mfpu=neon  '
             '-mfloat-abi=hard -mcpu=cortex-a9 -DNDEBUG -fno-inline '
             ' '
             '-shared -Wl,-O1 -Wl,--hash-style=gnu -Wl,--as-needed -Wl,-O1 '
             '-Wl,--hash-style=gnu -Wl,--as-needed',
 'LDVERSION': '3.5m',
 'LIB': 'lib',
 'LIBC': '',
 'LIBDEST': '/usr/lib/python3.5',
 'LIBDIR': '/usr/lib',
 'LIBFFI_INCLUDEDIR': '/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2/usr/lib/libffi-3.2.1/include',
 'LIBM': '-lm',
 'LIBOBJDIR': 'Python/',
 'LIBOBJS': '',
 'LIBPC': '/usr/lib/pkgconfig',
 'LIBPL': '/usr/lib/python3.5/config-3.5m',
 'LIBRARY': 'libpython3.5m.a',
 'LIBRARY_OBJS': '\\',
 'LIBRARY_OBJS_OMIT_FROZEN': '\\',
 'LIBS': '-lpthread -ldl  -lpthread -lutil',
 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
 'LINKCC': 'arm-jdsu-linux-gnueabi-gcc  -march=armv7-a -marm -mfpu=neon  '
           '-mfloat-abi=hard -mcpu=cortex-a9 -DNDEBUG -fno-inline '
           '',
 'LINKFORSHARED': '-Xlinker -export-dynamic',
 'LIPO_32BIT_FLAGS': '',
 'LLVM_PROF_ERR': 'no',
 'LLVM_PROF_FILE': '',
 'LLVM_PROF_MERGER': 'true',
 'LN': 'ln',
 'LOCALMODLIBS': '',
 'LOG1P_DROPS_ZERO_SIGN': 0,
 'MACHDEP': 'linux',
 'MACHDEPPATH': ':plat-linux',
 'MACHDEPS': 'plat-linux',
 'MACHDEP_OBJS': '',
 'MACHDESTLIB': '/usr/lib/python3.5',
 'MACOSX_DEPLOYMENT_TARGET': '',
 'MAINCC': 'arm-jdsu-linux-gnueabi-gcc  -march=armv7-a -marm -mfpu=neon  '
           '-mfloat-abi=hard -mcpu=cortex-a9 -DNDEBUG -fno-inline '
           '',
 'MAJOR_IN_MKDEV': 0,
 'MAJOR_IN_SYSMACROS': 0,
 'MAKESETUP': '../Python-3.5.2/Modules/makesetup',
 'MANDIR': '/usr/share/man',
 'MKDIR_P': '/bin/mkdir -p',
 'MODLIBS': '',
 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  '
            'Modules/posixmodule.o  Modules/errnomodule.o  '
            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
            'Modules/_operator.o  Modules/_collectionsmodule.o  '
            'Modules/itertoolsmodule.o  Modules/atexitmodule.o  '
            'Modules/_stat.o  Modules/timemodule.o  Modules/_localemodule.o  '
            'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
            'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
            'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
            'Modules/_tracemalloc.o Modules/hashtable.o  '
            'Modules/symtablemodule.o  Modules/xxsubtype.o',
 'MODULE_OBJS': '\\',
 'MULTIARCH': '',
 'MVWDELCH_IS_EXPRESSION': 1,
 'NO_AS_NEEDED': '-Wl,--no-as-needed',
 'OBJECT_OBJS': '\\',
 'OPCODETARGETGEN': '\\',
 'OPCODETARGETGEN_FILES': '\\',
 'OPCODETARGETS_H': '\\',
 'OPCODE_H': '../Python-3.5.2/Include/opcode.h',
 'OPCODE_H_DIR': '../Python-3.5.2/Include',
 'OPCODE_H_GEN': '/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux/usr/bin/python3-native/python3  '
                 '../Python-3.5.2/Tools/scripts/generate_opcode_h.py '
                 '../Python-3.5.2/Lib/opcode.py '
                 '../Python-3.5.2/Include/opcode.h',
 'OPCODE_H_SCRIPT': '../Python-3.5.2/Tools/scripts/generate_opcode_h.py',
 'OPT': '-DNDEBUG -g  -O3 -Wall -Wstrict-prototypes',
 'OTHER_LIBTOOL_OPT': '',
 'PACKAGE_BUGREPORT': 0,
 'PACKAGE_NAME': 0,
 'PACKAGE_STRING': 0,
 'PACKAGE_TARNAME': 0,
 'PACKAGE_URL': 0,
 'PACKAGE_VERSION': 0,
 'PARSER_HEADERS': '\\',
 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
 'PGEN': 'Parser/pgen',
 'PGENOBJS': '\\ \\',
 'PGENSRCS': '\\ \\',
 'PGOBJS': '\\',
 'PGO_PROF_GEN_FLAG': '-fprofile-generate',
 'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
 'PGSRCS': '\\',
 'PLATDIR': 'plat-linux',
 'POBJS': '\\',
 'POSIX_SEMAPHORES_NOT_ENABLED': 0,
 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb '
                 'test_multiprocessing_fork test_multiprocessing_forkserver '
                 'test_multiprocessing_main_handling '
                 'test_multiprocessing_spawn test_subprocess',
 'PSRCS': '\\',
 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 0,
 'PURIFY': '',
 'PY3LIBRARY': 'libpython3.so',
 'PYLONG_BITS_IN_DIGIT': 0,
 'PYTHON': 'python',
 'PYTHONFRAMEWORK': '',
 'PYTHONFRAMEWORKDIR': 'no-framework',
 'PYTHONFRAMEWORKINSTALLDIR': '',
 'PYTHONFRAMEWORKPREFIX': '',
 'PYTHONPATH': ':plat-linux',
 'PYTHON_FOR_BUILD': '_PYTHON_PROJECT_BASE=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build '
                     '_PYTHON_HOST_PLATFORM=$(_PYTHON_HOST_PLATFORM) '
                     'PYTHONPATH=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux/usr/lib/python3.5/lib-dynload/:/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build/build/lib.linux-arm-3.5:/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/Python-3.5.2/Lib:/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/Python-3.5.2/Lib/plat-linux '
                     'python3.5',
 'PYTHON_HEADERS': '\\',
 'PYTHON_OBJS': '\\',
 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall '
              '-Wstrict-prototypes -O2 -pipe -g -feliminate-unused-debug-types '
              '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
              '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
              '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2=  '
              '-O2 -pipe -g -feliminate-unused-debug-types '
              '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
              '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
              '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2=',
 'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall '
                   '-Wstrict-prototypes -O2 -pipe -g '
                   '-feliminate-unused-debug-types '
                   '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
                   '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
                   '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2=  '
                   '-O2 -pipe -g -feliminate-unused-debug-types '
                   '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0=/usr/src/debug/python3/3.5.2-r1.0 '
                   '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/x86_64-linux= '
                   '-fdebug-prefix-map=/mnt/Yocto/dev_morty/eotdrv2/tmp/sysroots/eotdrv2= '
                   '-Werror=declaration-after-statement -I. -IInclude '
                   '-I../Python-3.5.2/Include -fPIC -DPy_BUILD_CORE',
 'PY_CPPFLAGS': '-I. -IInclude -I../Python-3.5.2/Include',
 'PY_FORMAT_LONG_LONG': '"ll"',
 'PY_FORMAT_SIZE_T': '"z"',
 'PY_LDFLAGS': '-Wl,-O1 -Wl,--hash-style=gnu -Wl,--as-needed -Wl,-O1 '
               '-Wl,--hash-style=gnu -Wl,--as-needed',
 'Py_DEBUG': 0,
 'Py_ENABLE_SHARED': 1,
 'Py_HASH_ALGORITHM': 0,
 'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
 'RANLIB': 'arm-jdsu-linux-gnueabi-ranlib',
 'READELF': 'arm-jdsu-linux-gnueabi-readelf',
 'RESSRCDIR': 'Mac/Resources/framework',
 'RETSIGTYPE': 'void',
 'RUNSHARED': '',
 'SCRIPTDIR': '/usr/lib',
 'SETPGRP_HAVE_ARG': 0,
 'SGI_ABI': '',
 'SHELL': '/bin/sh',
 'SHLIBS': '-lpthread -ldl  -lpthread -lutil',
 'SHLIB_SUFFIX': '.so',
 'SIGNAL_OBJS': '',
 'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
 'SITEPATH': '',
 'SIZEOF_DOUBLE': 8,
 'SIZEOF_FLOAT': 4,
 'SIZEOF_FPOS_T': 16,
 'SIZEOF_INT': 4,
 'SIZEOF_LONG': 4,
 'SIZEOF_LONG_DOUBLE': 8,
 'SIZEOF_LONG_LONG': 8,
 'SIZEOF_OFF_T': 8,
 'SIZEOF_PID_T': 4,
 'SIZEOF_PTHREAD_T': 4,
 'SIZEOF_SHORT': 2,
 'SIZEOF_SIZE_T': 4,
 'SIZEOF_TIME_T': 4,
 'SIZEOF_UINTPTR_T': 4,
 'SIZEOF_VOID_P': 4,
 'SIZEOF_WCHAR_T': 4,
 'SIZEOF__BOOL': 1,
 'SOABI': 'cpython-35m-arm-linux-gnueabihf',
 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
 'SRC_GDB_HOOKS': '../Python-3.5.2/Tools/gdb/libpython.py',
 'STDC_HEADERS': 1,
 'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
 'STRIPFLAG': '-s',
 'SUBDIRS': '',
 'SUBDIRSTOO': 'Include Lib Misc',
 'SYSLIBS': '-lm',
 'SYS_SELECT_WITH_SYS_TIME': 1,
 'TANH_PRESERVES_ZERO_SIGN': 0,
 'TCLTK_INCLUDES': '',
 'TCLTK_LIBS': '',
 'TESTOPTS': '',
 'TESTPATH': '',
 'TESTPYTHON': 'python',
 'TESTPYTHONOPTS': '',
 'TESTRUNNER': 'python ../Python-3.5.2/Tools/scripts/run_tests.py',
 'TESTTIMEOUT': 3600,
 'THREADOBJ': 'Python/thread.o',
 'TIMEMODULE_LIB': 0,
 'TIME_WITH_SYS_TIME': 1,
 'TM_IN_SYS_TIME': 0,
 'UNICODE_DEPS': '\\',
 'UNIVERSALSDK': '',
 'USE_COMPUTED_GOTOS': 0,
 'USE_INLINE': 1,
 'VA_LIST_IS_ARRAY': 0,
 'VERSION': '3.5',
 'VPATH': '../Python-3.5.2',
 'WANT_SIGFPE_HANDLER': 0,
 'WINDOW_HAS_FLAGS': 1,
 'WITH_DOC_STRINGS': 1,
 'WITH_DYLD': 0,
 'WITH_LIBINTL': 0,
 'WITH_NEXT_FRAMEWORK': 0,
 'WITH_PYMALLOC': 1,
 'WITH_THREAD': 1,
 'WITH_TSC': 0,
 'WITH_VALGRIND': 0,
 'X87_DOUBLE_ROUNDING': 0,
 'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
 'abs_builddir': '/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build',
 'abs_srcdir': '/mnt/Yocto/dev_morty/eotdrv2/tmp/work/cortexa9hf-neon-jdsu-linux-gnueabi/python3/3.5.2-r1.0/build/../Python-3.5.2',
 'cross_compiling': 'yes',
 'datarootdir': '/usr/share',
 'exec_prefix': '/usr',
 'prefix': '/usr',
 'srcdir': '../Python-3.5.2'}
